@@ -59,13 +59,31 @@
 
 using namespace TechDraw;
 
-void DrawDimHelper::makeExtentDim(DrawViewPart* dvp, std::vector<std::string> edgeNames,
+DrawViewDimension* DrawDimHelper::makeExtentDim(DrawViewPart* dvp,
+    const std::string& dimType, ReferenceVector references2d)
+{
+    std::vector<std::string> edgeNames;
+    for (auto& ref : references2d) {
+        if (ref.getSubName().empty()) {
+            continue;
+        }
+        std::string geomType = DrawUtil::getGeomTypeFromName(ref.getSubName());
+        if (geomType == "Edge") {
+            edgeNames.push_back(ref.getSubName());
+        }
+    }
+    int direction = dimType == "DistanceX" ? 0 : dimType == "DistanceY" ? 1 : 2;
+
+    return makeExtentDim(dvp, edgeNames, direction);
+}
+
+DrawViewDimension* DrawDimHelper::makeExtentDim(DrawViewPart* dvp, std::vector<std::string> edgeNames,
                                   int direction)
 {
     //    Base::Console().Message("DDH::makeExtentDim() - dvp: %s edgeNames: %d\n",
     //                            dvp->Label.getValue(), edgeNames.size());
     if (!dvp) {
-        return;
+        return nullptr;
     }
 
     std::string dimType = "DistanceX";
@@ -74,21 +92,26 @@ void DrawDimHelper::makeExtentDim(DrawViewPart* dvp, std::vector<std::string> ed
         dimType = "DistanceY";
         dimNum = 1;
     }
+    else if (direction == LENGTH) {
+        dimType = "Distance";
+        dimNum = 2;
+    }
 
-    TechDraw::DrawPage* page = dvp->findParentPage();
+    DrawPage* page = dvp->findParentPage();
     std::string pageName = page->getNameInDocument();
 
     App::Document* doc = dvp->getDocument();
     std::string dimName = doc->getUniqueObjectName("DimExtent");
     Base::Interpreter().runStringArg(
         "App.activeDocument().addObject('TechDraw::DrawViewDimExtent', '%s')", dimName.c_str());
-    Base::Interpreter().runStringArg(
+        Base::Interpreter().runStringArg(
+            "App.activeDocument().%s.translateLabel('DrawViewDimExtent', 'DimExtent', '%s')",
+              dimName.c_str(), dimName.c_str());    Base::Interpreter().runStringArg(
         "App.activeDocument().%s.Type = '%s'", dimName.c_str(), dimType.c_str());
     Base::Interpreter().runStringArg(
         "App.activeDocument().%s.DirExtent = %d", dimName.c_str(), dimNum);
 
-    TechDraw::DrawViewDimExtent* dimExt =
-        dynamic_cast<TechDraw::DrawViewDimExtent*>(doc->getObject(dimName.c_str()));
+    auto* dimExt = dynamic_cast<DrawViewDimExtent*>(doc->getObject(dimName.c_str()));
     if (!dimExt) {
         throw Base::TypeError("Dim extent not found");
     }
@@ -111,6 +134,14 @@ void DrawDimHelper::makeExtentDim(DrawViewPart* dvp, std::vector<std::string> ed
                                      dimName.c_str());
 
     dimExt->recomputeFeature();
+
+    return dimExt;
+}
+
+void DrawDimHelper::makeExtentDim3d(DrawViewPart* dvp, const std::string& dimType, ReferenceVector references3d)
+{
+    int direction = dimType == "DistanceX" ? 0 : dimType == "DistanceY" ? 1 : 2;
+    return makeExtentDim3d(dvp, references3d, direction);
 }
 
 void DrawDimHelper::makeExtentDim3d(DrawViewPart* dvp, ReferenceVector references, int direction)
@@ -128,20 +159,21 @@ void DrawDimHelper::makeExtentDim3d(DrawViewPart* dvp, ReferenceVector reference
         dimNum = 1;
     }
 
-    TechDraw::DrawPage* page = dvp->findParentPage();
+    DrawPage* page = dvp->findParentPage();
     std::string pageName = page->getNameInDocument();
 
     App::Document* doc = dvp->getDocument();
     std::string dimName = doc->getUniqueObjectName("DimExtent");
     Base::Interpreter().runStringArg(
         "App.activeDocument().addObject('TechDraw::DrawViewDimExtent', '%s')", dimName.c_str());
-    Base::Interpreter().runStringArg(
+        Base::Interpreter().runStringArg(
+            "App.activeDocument().%s.translateLabel('DrawViewDimExtent', 'DimExtent', '%s')",
+              dimName.c_str(), dimName.c_str());    Base::Interpreter().runStringArg(
         "App.activeDocument().%s.Type = '%s'", dimName.c_str(), dimType.c_str());
     Base::Interpreter().runStringArg(
         "App.activeDocument().%s.DirExtent = %d", dimName.c_str(), dimNum);
 
-    TechDraw::DrawViewDimExtent* dimExt =
-        dynamic_cast<TechDraw::DrawViewDimExtent*>(doc->getObject(dimName.c_str()));
+    auto* dimExt = dynamic_cast<DrawViewDimExtent*>(doc->getObject(dimName.c_str()));
     if (!dimExt) {
         throw Base::TypeError("Dim extent not found");
     }
@@ -304,7 +336,11 @@ DrawDimHelper::minMax3d(DrawViewPart* dvp, ReferenceVector references, int direc
     TopoDS_Compound comp;
     builder.MakeCompound(comp);
     for (auto& ref : references) {
-        builder.Add(comp, ref.getGeometry());
+        auto tempGeom = ref.getGeometry();
+        if (tempGeom.IsNull()) {
+            continue;
+        }
+        builder.Add(comp, tempGeom);
     }
     Base::Vector3d centroid = dvp->getOriginalCentroid();
     TopoDS_Shape centeredShape =//this result is a throw away. We will work with comp.
@@ -398,11 +434,14 @@ DrawDimHelper::makeDistDim(DrawViewPart* dvp, std::string dimType,
 
     std::vector<TechDraw::VertexPtr> gVerts = dvp->getVertexGeometry();
 
+    // invert the point so the math works correctly
     Base::Vector3d cleanMin = DrawUtil::invertY(inMin);
+   cleanMin = CosmeticVertex::makeCanonicalPoint(dvp, cleanMin);
     std::string tag1 = dvp->addCosmeticVertex(cleanMin);
     int iGV1 = dvp->add1CVToGV(tag1);
 
     Base::Vector3d cleanMax = DrawUtil::invertY(inMax);
+   cleanMax = CosmeticVertex::makeCanonicalPoint(dvp, cleanMax);
     std::string tag2 = dvp->addCosmeticVertex(cleanMax);
     int iGV2 = dvp->add1CVToGV(tag2);
 
@@ -426,11 +465,16 @@ DrawDimHelper::makeDistDim(DrawViewPart* dvp, std::string dimType,
     if (extent) {
         Base::Interpreter().runStringArg(
             "App.activeDocument().addObject('TechDraw::DrawViewDimExtent', '%s')", dimName.c_str());
+        Base::Interpreter().runStringArg(
+            "App.activeDocument().%s.translateLabel('DrawViewDimExtent', 'DimExtent', '%s')",
+              dimName.c_str(), dimName.c_str());
     }
     else {
-
         Base::Interpreter().runStringArg(
             "App.activeDocument().addObject('TechDraw::DrawViewDimension', '%s')", dimName.c_str());
+        Base::Interpreter().runStringArg(
+            "App.activeDocument().%s.translateLabel('DrawViewDimimension', 'Dimension', '%s')",
+              dimName.c_str(), dimName.c_str());
     }
 
     Base::Interpreter().runStringArg(
